@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -424,11 +424,15 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def list_gateways(
         self,
-        request: apigateway.ListGatewaysRequest = None,
+        request: Union[apigateway.ListGatewaysRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -438,7 +442,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Lists Gateways in a given project and location.
 
         Args:
-            request (google.cloud.apigateway_v1.types.ListGatewaysRequest):
+            request (Union[google.cloud.apigateway_v1.types.ListGatewaysRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.ListGateways
             parent (str):
@@ -508,7 +512,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def get_gateway(
         self,
-        request: apigateway.GetGatewayRequest = None,
+        request: Union[apigateway.GetGatewayRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -518,7 +522,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Gets details of a single Gateway.
 
         Args:
-            request (google.cloud.apigateway_v1.types.GetGatewayRequest):
+            request (Union[google.cloud.apigateway_v1.types.GetGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.GetGateway
             name (str):
@@ -583,7 +587,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def create_gateway(
         self,
-        request: apigateway.CreateGatewayRequest = None,
+        request: Union[apigateway.CreateGatewayRequest, dict] = None,
         *,
         parent: str = None,
         gateway: apigateway.Gateway = None,
@@ -596,7 +600,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         location.
 
         Args:
-            request (google.cloud.apigateway_v1.types.CreateGatewayRequest):
+            request (Union[google.cloud.apigateway_v1.types.CreateGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.CreateGateway
             parent (str):
@@ -686,7 +690,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def update_gateway(
         self,
-        request: apigateway.UpdateGatewayRequest = None,
+        request: Union[apigateway.UpdateGatewayRequest, dict] = None,
         *,
         gateway: apigateway.Gateway = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -697,7 +701,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Updates the parameters of a single Gateway.
 
         Args:
-            request (google.cloud.apigateway_v1.types.UpdateGatewayRequest):
+            request (Union[google.cloud.apigateway_v1.types.UpdateGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.UpdateGateway
             gateway (google.cloud.apigateway_v1.types.Gateway):
@@ -783,7 +787,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def delete_gateway(
         self,
-        request: apigateway.DeleteGatewayRequest = None,
+        request: Union[apigateway.DeleteGatewayRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -793,7 +797,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Deletes a single Gateway.
 
         Args:
-            request (google.cloud.apigateway_v1.types.DeleteGatewayRequest):
+            request (Union[google.cloud.apigateway_v1.types.DeleteGatewayRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.DeleteGateway
             name (str):
@@ -875,7 +879,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def list_apis(
         self,
-        request: apigateway.ListApisRequest = None,
+        request: Union[apigateway.ListApisRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -885,7 +889,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Lists Apis in a given project and location.
 
         Args:
-            request (google.cloud.apigateway_v1.types.ListApisRequest):
+            request (Union[google.cloud.apigateway_v1.types.ListApisRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.ListApis
             parent (str):
@@ -955,7 +959,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def get_api(
         self,
-        request: apigateway.GetApiRequest = None,
+        request: Union[apigateway.GetApiRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -965,7 +969,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Gets details of a single Api.
 
         Args:
-            request (google.cloud.apigateway_v1.types.GetApiRequest):
+            request (Union[google.cloud.apigateway_v1.types.GetApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.GetApi
             name (str):
@@ -1026,7 +1030,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def create_api(
         self,
-        request: apigateway.CreateApiRequest = None,
+        request: Union[apigateway.CreateApiRequest, dict] = None,
         *,
         parent: str = None,
         api: apigateway.Api = None,
@@ -1038,7 +1042,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Creates a new Api in a given project and location.
 
         Args:
-            request (google.cloud.apigateway_v1.types.CreateApiRequest):
+            request (Union[google.cloud.apigateway_v1.types.CreateApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.CreateApi
             parent (str):
@@ -1127,7 +1131,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def update_api(
         self,
-        request: apigateway.UpdateApiRequest = None,
+        request: Union[apigateway.UpdateApiRequest, dict] = None,
         *,
         api: apigateway.Api = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -1138,7 +1142,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Updates the parameters of a single Api.
 
         Args:
-            request (google.cloud.apigateway_v1.types.UpdateApiRequest):
+            request (Union[google.cloud.apigateway_v1.types.UpdateApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.UpdateApi
             api (google.cloud.apigateway_v1.types.Api):
@@ -1221,7 +1225,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def delete_api(
         self,
-        request: apigateway.DeleteApiRequest = None,
+        request: Union[apigateway.DeleteApiRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1231,7 +1235,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Deletes a single Api.
 
         Args:
-            request (google.cloud.apigateway_v1.types.DeleteApiRequest):
+            request (Union[google.cloud.apigateway_v1.types.DeleteApiRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.DeleteApi
             name (str):
@@ -1313,7 +1317,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def list_api_configs(
         self,
-        request: apigateway.ListApiConfigsRequest = None,
+        request: Union[apigateway.ListApiConfigsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1323,7 +1327,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Lists ApiConfigs in a given project and location.
 
         Args:
-            request (google.cloud.apigateway_v1.types.ListApiConfigsRequest):
+            request (Union[google.cloud.apigateway_v1.types.ListApiConfigsRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.ListApiConfigs
             parent (str):
@@ -1393,7 +1397,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def get_api_config(
         self,
-        request: apigateway.GetApiConfigRequest = None,
+        request: Union[apigateway.GetApiConfigRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1403,7 +1407,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Gets details of a single ApiConfig.
 
         Args:
-            request (google.cloud.apigateway_v1.types.GetApiConfigRequest):
+            request (Union[google.cloud.apigateway_v1.types.GetApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.GetApiConfig
             name (str):
@@ -1465,7 +1469,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def create_api_config(
         self,
-        request: apigateway.CreateApiConfigRequest = None,
+        request: Union[apigateway.CreateApiConfigRequest, dict] = None,
         *,
         parent: str = None,
         api_config: apigateway.ApiConfig = None,
@@ -1478,7 +1482,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         location.
 
         Args:
-            request (google.cloud.apigateway_v1.types.CreateApiConfigRequest):
+            request (Union[google.cloud.apigateway_v1.types.CreateApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.CreateApiConfig
             parent (str):
@@ -1566,7 +1570,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def update_api_config(
         self,
-        request: apigateway.UpdateApiConfigRequest = None,
+        request: Union[apigateway.UpdateApiConfigRequest, dict] = None,
         *,
         api_config: apigateway.ApiConfig = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -1577,7 +1581,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Updates the parameters of a single ApiConfig.
 
         Args:
-            request (google.cloud.apigateway_v1.types.UpdateApiConfigRequest):
+            request (Union[google.cloud.apigateway_v1.types.UpdateApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.UpdateApiConfig
             api_config (google.cloud.apigateway_v1.types.ApiConfig):
@@ -1661,7 +1665,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
 
     def delete_api_config(
         self,
-        request: apigateway.DeleteApiConfigRequest = None,
+        request: Union[apigateway.DeleteApiConfigRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1671,7 +1675,7 @@ class ApiGatewayServiceClient(metaclass=ApiGatewayServiceClientMeta):
         r"""Deletes a single ApiConfig.
 
         Args:
-            request (google.cloud.apigateway_v1.types.DeleteApiConfigRequest):
+            request (Union[google.cloud.apigateway_v1.types.DeleteApiConfigRequest, dict]):
                 The request object. Request message for
                 ApiGatewayService.DeleteApiConfig
             name (str):
